==> CALIB_1.18.0.zip: CALIB/doc/quickstart.R <==
###################################################
### chunk number 1:  eval=FALSE
###################################################
## #line 56 "quickstart.Rnw"
## library(CALIB)
## calibReadMe()


###################################################
### chunk number 2: 
###################################################
#line 98 "quickstart.Rnw"
library(CALIB)
path<-system.file("arraydata", package="CALIB")
dir(system.file("arraydata", package="CALIB")) 


###################################################
### chunk number 3: 
###################################################
#line 107 "quickstart.Rnw"
datapath <- system.file("arraydata", package="CALIB")
targets <- readTargets("targets.txt",path=datapath)
targets


###################################################
### chunk number 4: 
###################################################
#line 117 "quickstart.Rnw"
RG <- read.rg(targets$FileName,columns=list(Rf="CH1_NBC_INT",Gf="CH2_NBC_INT",Rb="CH1_SPOT_BKGD",Gb="CH2_SPOT_BKGD",RArea="CH1_SPOT_AREA",GArea="CH2_SPOT_AREA"),path=datapath)


###################################################
### chunk number 5: 
###################################################
#line 123 "quickstart.Rnw"
filename <- "annotation.txt"
fullname <- file.path(datapath,filename)
annotation <- read.table(file=fullname,header=T,fill=T,quote="",sep="\t")
RG$genes <- annotation


###################################################
### chunk number 6: 
###################################################
#line 132 "quickstart.Rnw"
types<-readSpotTypes(path=datapath)
types
spotstatus<-controlStatus(types,RG$genes)
RG$genes$Status<-spotstatus


###################################################
### chunk number 7: 
###################################################
#line 141 "quickstart.Rnw"
concfile<-"conc.txt"
spike<-read.spike(RG,file=concfile,path=datapath)


###################################################
### chunk number 8: spikeci
###################################################
#line 148 "quickstart.Rnw"
arraynum <- 1
plotSpikeCI(spike,array=arraynum)


###################################################
### chunk number 9: 
###################################################
#line 164 "quickstart.Rnw"
parameter<-estimateParameter(spike,RG,bc=F,area=T,errormodel="M")


###################################################
### chunk number 10: spikehi
###################################################
#line 170 "quickstart.Rnw"
plotSpikeHI(spike,parameter,array=arraynum)


###################################################
### chunk number 11: 
###################################################
#line 186 "quickstart.Rnw"
array<-c(1,1,2,2)
condition<-c(1,2,2,1)
dye<-c(1,2,1,2)
idcol<-"CLONE_ID"
## here, we normalize the first ten genes as example.
cloneid<-RG$genes[1:10,idcol]
normdata<-normalizeData(RG,parameter,array,condition,dye,idcol=idcol,cloneid=cloneid)
normdata

==> CALIB_1.44.0.zip: CALIB/doc/quickstart.R <==
### R code from vignette source 'quickstart.Rnw'

###################################################
### code chunk number 1: quickstart.Rnw:55-57 (eval = FALSE)
###################################################
## library(CALIB)
## calibReadMe()


###################################################
### code chunk number 2: quickstart.Rnw:97-100
###################################################
library(CALIB)
path<-system.file("arraydata", package="CALIB")
dir(system.file("arraydata", package="CALIB")) 


###################################################
### code chunk number 3: quickstart.Rnw:106-109
###################################################
datapath <- system.file("arraydata", package="CALIB")
targets <- readTargets("targets.txt",path=datapath)
targets


###################################################
### code chunk number 4: quickstart.Rnw:116-117
###################################################
RG <- read.rg(targets$FileName,columns=list(Rf="CH1_NBC_INT",Gf="CH2_NBC_INT",Rb="CH1_SPOT_BKGD",Gb="CH2_SPOT_BKGD",RArea="CH1_SPOT_AREA",GArea="CH2_SPOT_AREA"),path=datapath)


###################################################
### code chunk number 5: quickstart.Rnw:122-126
###################################################
filename <- "annotation.txt"
fullname <- file.path(datapath,filename)
annotation <- read.table(file=fullname,header=T,fill=T,quote="",sep="\t")
RG$genes <- annotation


###################################################
### code chunk number 6: quickstart.Rnw:131-135
###################################################
types<-readSpotTypes(path=datapath)
types
spotstatus<-controlStatus(types,RG$genes)
RG$genes$Status<-spotstatus


###################################################
### code chunk number 7: quickstart.Rnw:140-142
###################################################
concfile<-"conc.txt"
spike<-read.spike(RG,file=concfile,path=datapath)


###################################################
### code chunk number 8: spikeci
###################################################
arraynum <- 1
plotSpikeCI(spike,array=arraynum)


###################################################
### code chunk number 9: quickstart.Rnw:163-164
###################################################
parameter<-estimateParameter(spike,RG,bc=F,area=T,errormodel="M")


###################################################
### code chunk number 10: spikehi
###################################################
plotSpikeHI(spike,parameter,array=arraynum)


###################################################
### code chunk number 11: quickstart.Rnw:185-193
###################################################
array<-c(1,1,2,2)
condition<-c(1,2,2,1)
dye<-c(1,2,1,2)
idcol<-"CLONE_ID"
## here, we normalize the first ten genes as example.
cloneid<-RG$genes[1:10,idcol]
normdata<-normalizeData(RG,parameter,array,condition,dye,idcol=idcol,cloneid=cloneid)
normdata
